## 102003053
### It calculates topsis for a given data in csv file.

### Installation
## pip install 102003053



## License
### © 2023 Amit Kumar

### This repository is licensed under the MIT license. See LICENSE for details.